using UnityEngine;
using System.Collections;

public class eagleScript : CigObjectInterface {
	public GameObject m_gameObject;
	private bool showGUI;
	public AudioSource m_womanAudioSource;
	public AudioClip m_SmookingClip;
	public AudioClip m_CigaretesDestroyClip;
	public AudioClip m_StartSmookingClip;
	public AudioClip m_BaldEagleClip;
	public AudioClip m_LoopEagleClip;
	public GameObject m_Cigaretes;
	public GameObject m_Lighter;
	public ParticleSystem m_CigaretePS;
	public ParticleSystem m_MountSmokePS;
	public ParticleSystem m_LighterPS;
	private bool firstStart = true;

	// Use this for initialization
	void Start () {
		this.showGUI = true;
		this.m_gameObject.animation.wrapMode = WrapMode.Loop;
		
		this.m_Cigaretes.renderer.enabled = false;
		this.m_Lighter.renderer.enabled = false;
		
		this.m_CigaretePS.enableEmission = false;
		this.m_MountSmokePS.enableEmission = false;
		this.m_LighterPS.enableEmission = false;
	}
	
	
	public override void init()
	{
		if (this.firstStart)
		{
			this.m_gameObject.animation.Rewind();
			this.m_gameObject.animation.Play("smooking");
			this.m_gameObject.animation.wrapMode = WrapMode.Loop;
			this.m_womanAudioSource.clip = this.m_SmookingClip;
			this.m_womanAudioSource.loop = true;
			this.m_womanAudioSource.Play();
			this.firstStart = false;
			
			this.m_Cigaretes.renderer.enabled = true;
			this.m_Lighter.renderer.enabled = false;
			
			this.m_CigaretePS.enableEmission = true;
			this.m_MountSmokePS.enableEmission = true;
			this.m_LighterPS.enableEmission = false;
		}
	}
	
	public override void lose()
	{
		
	}
	
	public override void restart()
	{
		this.showGUI = true;
		this.firstStart = true;
		this.m_gameObject.animation.wrapMode = WrapMode.Loop;
		
		this.m_womanAudioSource.Stop();
	
		this.m_Cigaretes.renderer.enabled = false;
		this.m_Lighter.renderer.enabled = false;
		
		this.m_CigaretePS.enableEmission = false;
		this.m_MountSmokePS.enableEmission = false;
		this.m_LighterPS.enableEmission = false;
	}
	
	public override void SmokeOn()
	{
		this.showGUI = false;
		StartCoroutine(startOffAnimation());
	}
	
	public override void SmokeOff()
	{
		this.showGUI = false;
		this.startOnAnimation();
	}
	
	public override bool ShowGUI()
	{
		return this.showGUI;
	}

	private IEnumerator stopSmooking()
	{
		this.m_womanAudioSource.Stop();
		this.m_gameObject.animation.CrossFade("stop_smooking");
		this.m_gameObject.animation.wrapMode = WrapMode.Once;
		this.m_MountSmokePS.enableEmission = false;

		this.m_womanAudioSource.clip = this.m_CigaretesDestroyClip;
		this.m_womanAudioSource.loop = false;
		this.m_womanAudioSource.Play();
		
		this.m_gameObject.animation.PlayQueued("loop");
		
		yield return new WaitForSeconds(0.5f);
		this.m_Cigaretes.renderer.enabled = false;
		this.m_CigaretePS.enableEmission = false;
		
		yield return new WaitForSeconds(1.8f);
		this.m_womanAudioSource.clip = this.m_BaldEagleClip;
		this.m_womanAudioSource.loop = false;
		this.m_womanAudioSource.Play();

		yield return new WaitForSeconds(3.7f);
		this.showGUI = true;
		this.m_gameObject.animation.wrapMode = WrapMode.Loop;
		
		yield return new WaitForSeconds(3.0f);
		this.m_womanAudioSource.clip = this.m_LoopEagleClip;
		this.m_womanAudioSource.loop = true;
		this.m_womanAudioSource.Play();
	}
	
	private void startOnAnimation()
	{
		StartCoroutine(stopSmooking());
	}
	
	public IEnumerator startOffAnimation()
	{
		this.m_gameObject.animation.PlayQueued("start_smooking");
		this.m_gameObject.animation.wrapMode = WrapMode.Once;
		
		AnimationState state = this.m_gameObject.animation["loop - Queued Clone"];
		yield return new WaitForSeconds(state.length - (state.time % state.length));

		yield return new WaitForSeconds(0.7f);
		this.m_Cigaretes.renderer.enabled = true;
		this.m_Lighter.renderer.enabled = true;
		
		yield return new WaitForSeconds(1.0f);
	
		this.m_womanAudioSource.clip = this.m_StartSmookingClip;
		this.m_womanAudioSource.loop = false;
		this.m_womanAudioSource.Play();
		this.m_CigaretePS.enableEmission = true;

		this.m_gameObject.animation.PlayQueued("smooking", QueueMode.CompleteOthers);

		yield return new WaitForSeconds(0.1f);
		this.m_LighterPS.enableEmission = true;
		
		yield return new WaitForSeconds(0.7f);
		this.m_LighterPS.enableEmission = false;
		
		yield return new WaitForSeconds(0.9f);
		this.m_Lighter.renderer.enabled = false;
		
		yield return new WaitForSeconds(0.1f);
		
		state = this.m_gameObject.animation["start_smooking - Queued Clone"];
		yield return new WaitForSeconds(state.length - (state.time % state.length));
		this.m_womanAudioSource.clip = this.m_SmookingClip;
		this.m_womanAudioSource.loop = true;
		this.m_womanAudioSource.Play();
		
		yield return new WaitForSeconds(2.0f);
		this.m_MountSmokePS.enableEmission = true;
		this.m_gameObject.animation.wrapMode = WrapMode.Loop;
		this.showGUI = true;
	}
	
	void Update () {
		string data = "";
		foreach(AnimationState state in this.m_gameObject.animation)
		{
			data += "+(" + state.name + ")" + (state.time % state.length);
		}		
		Debug.Log(data);
	}
}
	