using UnityEngine;
using System.Collections;

public class horseScript : MonoBehaviour {
	enum ControllState
	{
		MOTOR,
		MANUAL,
	};

	enum HorseState
	{
		WAIT,
		GO_HOME,
		READY_FOR_RIDE,
		RIDE,
		HAPPY,
		JUMP,
		GO_TO_HELL,
	};
	
	enum Phase
	{
		NONE,
		PHASE_1,
		PHASE_2,
		PHASE_3,
		PHASE_4,
		PHASE_5,
		PHASE_6,
		PHASE_7,
		PHASE_8,
		PHASE_9,
	}
	
	private Vector3 targetPosition;
    private Vector3 directionVector;
    private Camera mainCamera;
	private ControllState controllState;
	private CharacterMotor motor;
	private Phase phase;
	private Phase homePhase;
	private Phase hellPhase;
	private HorseState horseState;
	
	public cowboyScript m_CowboyScript;
	public Vector3 m_homeDirection;
	public Vector3 m_homePosition;
	public float m_y = 0.0f;
    public float smooth = 0.0005f;	
	private float m_distance = 10.0f;
	
	private Vector3 initPosition;
	private Quaternion initRotation;
	private Vector3 startPosition;
	private Quaternion startRotation;
	
	private AudioSource m_HorseAudioSource;
	public AudioClip m_HorseOnBackLegsClip;
	public AudioClip m_RunClip;
	public AudioClip m_JumpClip;
	private bool unblock;
	private bool stopBackLegs;
	
	void Start() {
		this.m_HorseAudioSource = GetComponent(typeof(AudioSource)) as AudioSource;
		
		this.unblock = true;
		this.stopBackLegs = false;
		this.targetPosition = this.transform.position;
		this.controllState = ControllState.MANUAL;
		this.horseState = HorseState.WAIT;
		this.phase = Phase.NONE;
		this.homePhase = Phase.NONE;
		this.hellPhase = Phase.NONE;
		this.startPosition = this.transform.position;
		this.startRotation = this.transform.rotation;
		
		motor = GetComponent(typeof(CharacterMotor)) as CharacterMotor;
		if (motor==null) 
			Debug.Log("Motor is null!!");
	}
	
	private IEnumerator jump()
	{
		yield return new WaitForSeconds(0.6f);
		((NormalCharacterMotor)this.motor).jump();
	}
	
	private IEnumerator onBackLegs()
	{
		this.unblock = false;
		this.stopBackLegs = false;
		this.controllState = ControllState.MANUAL;
		this.m_HorseAudioSource.clip = this.m_HorseOnBackLegsClip;
		this.m_HorseAudioSource.loop = false;
		this.m_HorseAudioSource.Play();
		
		this.animation.CrossFade("on back legs");
		this.m_CowboyScript.OnBackLegs();
		
	    //motor.desiredMovementDirection = this.m_homeDirection;
		yield return new WaitForSeconds(3.0f);
		
		if (!this.stopBackLegs)
		{
			this.unblock = true;
			this.animation.PlayQueued("stay");
			this.m_CowboyScript.Riding();
			this.phase = Phase.PHASE_1;
			this.controllState = ControllState.MOTOR;
		}
	}
	
	/*

+-          --

      X
++          -+

	*/

	public void runHorse() 
	{
		switch (this.phase)
		{
			case Phase.PHASE_1:
				this.targetPosition.Set(-this.m_distance * 0.8f, this.m_y, -this.m_distance);
				this.phase = Phase.PHASE_2;
				break;
			case Phase.PHASE_2:
				this.targetPosition.Set(-this.m_distance * 0.4f, this.m_y, this.m_distance * 0.4f);
				this.phase = Phase.PHASE_3;
				break;
			case Phase.PHASE_3:
				this.targetPosition.Set(this.m_distance, this.m_y, this.m_distance * 0.4f);
				this.phase = Phase.PHASE_4;
				break;
			case Phase.PHASE_4:
				this.targetPosition.Set(this.m_distance * 1.3f, this.m_y, -this.m_distance * 1.3f);
				this.phase = Phase.PHASE_5;
				break;
			case Phase.PHASE_5:
				this.targetPosition.Set(-this.m_distance * 0.4f, this.m_y, this.m_distance * 0.4f);
				this.phase = Phase.PHASE_6;
				StartCoroutine(jump());
				break;
			case Phase.PHASE_6:
				this.targetPosition.Set(this.m_distance, this.m_y, this.m_distance * 0.4f);
				this.phase = Phase.PHASE_7;
				break;
			case Phase.PHASE_7:
				this.targetPosition.Set(this.m_distance, this.m_y, -this.m_distance);
				this.phase = Phase.PHASE_8;
				break;
			case Phase.PHASE_8:
				this.phase = Phase.PHASE_9;
				StartCoroutine(onBackLegs());
				break;
			case Phase.PHASE_9:
				transform.position = targetPosition;
				break;
		}
		
		this.controllState = ControllState.MOTOR;
	}

  public void goHomeAgain()
  {
		switch (this.homePhase)
		{
			case Phase.NONE:
				this.stopBackLegs = true;
				this.targetPosition.Set(this.m_distance, this.m_y, 0.0f);
				this.animation.CrossFade("run");
				this.animation.wrapMode = WrapMode.Loop;
				this.horseState = HorseState.GO_HOME;
				this.homePhase = Phase.PHASE_1;
				break;
			case Phase.PHASE_1:
	            transform.position = targetPosition;
				this.targetPosition.Set(this.m_homePosition.x, this.m_y, this.m_homePosition.z);
		        motor.desiredFacingDirection = this.m_homePosition - targetPosition;
				this.homePhase = Phase.PHASE_2;
				break;
			case Phase.PHASE_2:
				this.horseState = HorseState.READY_FOR_RIDE;
		        motor.desiredMovementDirection = Vector3.zero;
				motor.desiredFacingDirection = Vector3.zero;
				transform.position = this.initPosition;
				transform.rotation = this.initRotation;
				((NormalCharacterMotor)this.motor).RestartVelocity();
				this.horseState = HorseState.RIDE;
				this.controllState = ControllState.MANUAL;
				this.animation.CrossFade("stay");
				this.m_HorseAudioSource.Stop();
				this.animation.wrapMode = WrapMode.Loop;
				StartCoroutine(this.m_CowboyScript.startOffAnimation());
				this.homePhase = Phase.PHASE_3;
				break;
		}
  	}	
	
	public void restart()
	{
		this.m_HorseAudioSource.Stop();
		this.stopBackLegs = false;
		this.unblock = true;
		this.animation.CrossFade("stay");
		this.animation.wrapMode = WrapMode.Loop;
		this.targetPosition = this.startPosition;
		this.controllState = ControllState.MANUAL;
		this.horseState = HorseState.WAIT;
		this.phase = Phase.NONE;
		this.homePhase = Phase.NONE;
		this.hellPhase = Phase.NONE;

        motor.desiredMovementDirection = Vector3.zero;
		motor.desiredFacingDirection = Vector3.zero;
		transform.position = this.startPosition;
		transform.rotation = this.startRotation;
		((NormalCharacterMotor)this.motor).RestartVelocity();
	}
	
	public void goToTheHell()
	{
		switch (this.hellPhase)
		{
			case Phase.NONE:
				if (!this.animation.IsPlaying("run"))
				{
					this.animation.CrossFade("run");
				}
			
				this.controllState = ControllState.MOTOR;
				this.targetPosition = new Vector3(-7.0f, this.m_y, 7.0f);
				this.horseState = HorseState.GO_TO_HELL;
				this.hellPhase = Phase.PHASE_2;
				break;
			case Phase.PHASE_1:
				this.targetPosition = this.startPosition + new Vector3(5.0f, 0.0f, 0.0f);
				this.hellPhase = Phase.PHASE_2;
				break;
			case Phase.PHASE_2:
				this.targetPosition = this.startPosition;
				this.hellPhase = Phase.PHASE_3;
				break;
			case Phase.PHASE_3:
				this.restart();
				break;
		}
	}
	
	public void goHomeHorse()
	{
		this.controllState = ControllState.MANUAL;
		this.targetPosition.Set(this.m_homePosition.x, this.m_y, this.m_homePosition.z);
		this.horseState = HorseState.GO_HOME;
	}
	
	void Update() {
        // Apply direction
		if (this.controllState == ControllState.MANUAL)
		{
			if (this.horseState == HorseState.GO_HOME)
			{
		        Vector3 diff = targetPosition - transform.position;
				
				if (!this.animation.IsPlaying("run"))
				{
					if (this.unblock)
						this.animation.CrossFade("run");
					this.animation.wrapMode = WrapMode.Loop;
					this.m_HorseAudioSource.clip = this.m_RunClip;
					this.m_HorseAudioSource.loop = true;
					this.m_HorseAudioSource.Play();
				}
				
		        Vector3 direction = this.targetPosition - transform.position;
				direction.Normalize();
				transform.position = transform.position + (direction * 0.3f);
	
				if (diff.magnitude <= 0.65f)
				{
					this.horseState = HorseState.READY_FOR_RIDE;
					transform.position = this.targetPosition;
				}
			}
			else if (this.horseState == HorseState.READY_FOR_RIDE)
			{
				if (!this.animation.IsPlaying("stay"))
					this.animation.CrossFade("stay");
				
				this.m_HorseAudioSource.Stop();
				this.animation.wrapMode = WrapMode.Loop;
				this.initPosition = this.transform.position;
				this.initRotation = this.transform.rotation;
				StartCoroutine(this.m_CowboyScript.horseIsReadyCallback());
				this.horseState = HorseState.RIDE;
				this.phase = Phase.PHASE_1;
			}
		}
		else if (this.controllState == ControllState.MOTOR)
		{
			if (this.motor.jumping)
			{
				if (!this.animation.IsPlaying("jump"))
				{
					if (this.unblock)
						this.animation.CrossFade("jump");
					this.animation.wrapMode = WrapMode.Once;
					this.m_HorseAudioSource.clip = this.m_JumpClip;
					this.m_HorseAudioSource.loop = false;
					this.m_HorseAudioSource.Play();
					
					//this.animation.PlayQueued("run", QueueMode.CompleteOthers);
				}
			}
			else if (this.motor.grounded)
			{
				if (!this.animation.IsPlaying("run"))
				{
					if (this.unblock)
						this.animation.CrossFade("run");
					this.animation.wrapMode = WrapMode.Loop;
					this.m_HorseAudioSource.clip = this.m_RunClip;
					this.m_HorseAudioSource.loop = true;
					this.m_HorseAudioSource.Play();
				}
			}
				
	        // Apply direction
			Vector3 position = transform.position;
			position.y = this.m_y;
	        Vector3 diff = targetPosition - transform.position;
	        motor.desiredFacingDirection = diff.normalized;
	        motor.desiredMovementDirection = Vector3.forward;
	        transform.position = Vector3.MoveTowards(transform.position, targetPosition, smooth);
	
			//diff.y = this.m_y;
			if (diff.magnitude < 1.8f)//0.68
	        {
	            //transform.position = targetPosition;
	            //motor.desiredMovementDirection = this.m_homeDirection;
				//this.animation.CrossFade("stay");
				if (this.horseState == HorseState.GO_HOME)
					this.goHomeAgain();
				else if (this.horseState == HorseState.GO_TO_HELL)
					this.goToTheHell();
				else
					this.runHorse();
	        }
		}
	}
}